@@ -7,6 +7,7 @@ from email.mime.text import MIMEText
 from email.mime.base import MIMEBase 
 from email import encoders
 import wget
+import shutil
 
 invalid_txt = '''
 *****************************************************************************
@@ -19,12 +20,16 @@ Go back to the "Upload your own image" section
 '''
 
 def get_models():
-    os.mkdirs('models', exist_ok=True)
+    if not os.path.exists('models'):
+        os.mkdir('models')
+    else:
+        shutil.rmtree('models', ignore_errors=True)
+        os.mkdir('models')
     wget.download('https://assets.lbc.co.uk/2016/33/boris-johnson-3-1471423733-view-1.jpg', 'bj.jpg')
     wget.download('https://docs.google.com/uc?export=download&id=16oKgr1RuoUlYcGDqsByiPNa6rnGjhO9T', 'models/deploy.prototxt')
     wget.download('https://docs.google.com/uc?export=download&id=1O0M9K7iGFckmfXrbuGoQU9A_ZdLsUMXP', 'models/res10_300x300_ssd_iter_140000.caffemodel')
     wget.download('https://github.com/jonfernandes/dxc_helmet/raw/master/download/0.1.0/helmet_detector.h5', 'models/helmet_detector.h5')
-    print('Models downloaded ...')
+    print('\nModels downloaded ...')
 
 def check_image(img='image.jpg'):
     img = cv2.imread(img)
